@@ -2,22 +2,20 @@ import json
 
 import pytest
 
-from plenum.common.constants import PUBKEY
-from plenum.common.exceptions import BlowUp
-from plenum.common.util import cryptonymToHex
-
 # noinspection PyUnresolvedReferences
 from indy_client.test.cli.conftest \
     import faberMap as faberMapWithoutEndpointPubkey
-
 # noinspection PyUnresolvedReferences
 from indy_client.test.cli.test_tutorial import alice_accepted_faber_request, \
     aliceCli, preRequisite, faberCli, acmeCli, thriftCli, faberWithEndpointAdded, acmeWithEndpointAdded, \
     thriftWithEndpointAdded, walletCreatedForTestEnv, \
     faberInviteSyncedWithEndpoint, faberInviteSyncedWithoutEndpoint, \
     faberInviteLoadedByAlice, accept_request
-
 from indy_common.constants import ENDPOINT
+from plenum.common.constants import PUBKEY
+from plenum.common.util import cryptonymToHex
+
+whitelist = ['Exception in callback ensureReqCompleted']
 
 
 @pytest.fixture(scope="module")
@@ -34,6 +32,5 @@ def faberMap(faberMapWithoutEndpointPubkey):
 def test_request_not_accepted_if_agent_was_added_using_hex_as_pubkey(
         be, do, aliceCli, faberMap, preRequisite,
         syncedInviteAcceptedWithClaimsOut, faberInviteSyncedWithEndpoint):
-    with pytest.raises(BlowUp):
-        accept_request(be, do, aliceCli, faberMap,
-                       syncedInviteAcceptedWithClaimsOut)
+    accept_request(be, do, aliceCli, faberMap,
+                   expect='Exception in callback ensureReqCompleted')
